<template>
    <div class="app-container">
        <div class="filter-container">
            <div style="display: block">
                <div class="basic_search">
                    <span>区域：</span>
                    <el-select v-model="listQuery.filter.province" clearable filterable @change="changeArea('province')">
                        <el-option
                            v-for="item in provinceList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.city" prop="city" clearable filterable @change="changeArea('city')">
                        <el-option
                            v-for="item in cityList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.district" clearable filterable @change="changeArea('district')">
                        <el-option
                            v-for="item in districtList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.street"clearable filterable @change="changeArea('street')" >
                        <el-option
                            v-for="item in streetList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.committee" clearable filterable>
                        <el-option
                            v-for="item in committeeList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
            </div>
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px">
                    <span>按企业名称查：</span>
                    <el-input filterable clearable v-model="listQuery.filter.enterprisename" style="width:200px">
                    </el-input>
                </div>
                <div class="basic_search" style="margin-right: 10px">
                    <el-button style="margin-left: 10px;" type="primary"  @click="add('新增','')">添加</el-button>
                    <el-button  style="margin-left: 10px;" type="primary"  @click="searchData('新增','')">查询</el-button>
                </div>
            </div>

        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="LawManagementData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="单位名称" prop="enterprisename" align="center">
                </el-table-column>
                <el-table-column label="制度名称" prop="name" align="center">
                </el-table-column>
                <el-table-column label="制定时间" prop="settime" align="center">
                </el-table-column>
                <el-table-column label="上传时间" prop="createtime" align="center">
                </el-table-column>
                <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button type="text" @click="download(scope.row.url)">下载</el-button>
                        <el-button type="text" @click="add('修改',scope.row)">修改</el-button>
                        <el-button type="text" @click="deleteById(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>

        <el-dialog
            :visible.sync="lawManagementVisible"
            append-to-body
            :title="title"
            :close-on-click-modal="false"
            width="600px"
        >
            <el-form ref="dataForm" :rules="dataFormRules" :model="dataForm" label-position="right" label-width="140px"  width="600px">
                <el-form-item label="制度名称:" prop="year" >
                    <el-input v-model="dataForm.name" class="content_qw"/>
                </el-form-item>
                <el-form-item label="制定时间:" prop="settime" >
                    <el-date-picker
                        value-format="yyyy-MM-dd HH:mm:ss"
                        v-model="dataForm.settime"
                        type="date"
                        placeholder="选择日期时间">
                    </el-date-picker>
                </el-form-item>
                <el-form-item label="内容:" prop="year" >
                    <el-input type="textarea" :rows="3" v-model="dataForm.content" class="content_qw"/>
                </el-form-item>
                <el-form-item label="许可范围:" prop="upload">
                    <input id="upload" ref="upload"  type="file"/>
                </el-form-item>
            </el-form>
            <div  align="right">
                <el-button @click="lawManagementVisible = false">取消</el-button>
                <el-button type="primary" @click="submit()">确认</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {uploadUrl} from '@/assets/upload/url'
import {  getLawManagementList ,addLawAndSafety , updateLawAndSafety ,deleteLawAndSafety} from '@/api/lawAndSafety'
import { computePageCount } from '@/utils'
import {getCityListData, getProvinceListData} from "@/api/area";
export default {
    name: "organConstruction",
    props:["enterpriseId"],
    data(){
        return{
            title:'',
            tableKey:0,
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            searchContent:'',
            listQuery:{
                filter: {
                    enterprisename:'',
                    province:'',
                    city:'',
                    district:'',
                    street:'',
                    committee:'',
                    menu:'organConstruction',
                },
                pageIndex: 1,
                pageSize: 10
            },
            provinceList:[],
            cityList:[],
            districtList:[],
            streetList:[],
            committeeList:[],
            LawManagementData:[],
            lawManagementVisible:false,
            dataFormRules:{},
            dataForm:{
                name:'',
                settime:'',
                content:'',
                file:'',
                menu:'organConstruction',
            }
        }
    },
    created(){
        this.getLawManagementListData()
        this.getProvince()
    },
    methods:{
        async getLawManagementListData(){
            this.listLoading = true
            let res = await getLawManagementList(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.LawManagementData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        async getProvince(){
            let res = await getProvinceListData()
            if(res.data.code === "200"){
                this.provinceList = res.data.result.provinceList
            }
        },//获取省

        async changeArea(value){
            if(value === 'province'){
                this.listQuery.filter.city = ''
                this.listQuery.filter.district = ''
                this.listQuery.filter.street = ''
                this.listQuery.filter.committee = ''
                this.areaListQuery = {
                    type: 2,
                    parenttype: 1,
                    parentname: this.listQuery.filter.province,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.cityList = res.data.result
                }
            }else if(value === 'city'){
                this.listQuery.filter.district = ''
                this.listQuery.filter.street = ''
                this.listQuery.filter.committee = ''
                this.areaListQuery = {
                    type: 3,
                    parenttype: 2,
                    parentname: this.listQuery.filter.city,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.districtList = res.data.result
                }
            }else if(value === 'district'){
                this.listQuery.filter.street = ''
                this.listQuery.filter.committee = ''
                this.areaListQuery = {
                    type: 4,
                    parenttype: 3,
                    parentname: this.listQuery.filter.district,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.streetList = res.data.result
                }
            }else if(value === 'street'){
                this.listQuery.filter.committee = ''
                this.areaListQuery = {
                    type: 5,
                    parenttype: 4,
                    parentname: this.listQuery.filter.street,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.committeeList = res.data.result
                }
            }
        },//市、镇、街道、委员会
        searchData(){
            this.getLawManagementListData()
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getLawManagementListData()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getLawManagementListData()
        },

        add(title,value){

            this.lawManagementVisible = true
            if(this.title === '新增'){
                this.title = '新增'
                this.dataForm ={
                    name:'',
                    settime:'',
                    content:'',
                    file:'',
                    menu:'lawManagement',
                }
            }else{
                this.title = '修改'
                this.dataForm.name = value.name
                this.dataForm.settime = value.settime
                this.dataForm.content = value.content
                this.dataForm.file = value.file
                this.dataForm.menu = value.menu
            }
        },

        download(value){
            window.open(uploadUrl() + value, '_blank')
        },

        async submit(){
            this.dataForm.file = this.$refs["upload"].files[0]
            const formData = new FormData();
            for (const i in this.dataForm) {
                if (
                    this.dataForm[i] != undefined &&
                    this.dataForm[i].toString() != ""
                ) {
                    formData.append(i, this.dataForm[i]);
                }
            }
            if(this.title === '新增'){
                let res = await addLawAndSafety(formData)
                if(res.data.code === '200'){
                    this.$refs["upload"].value = ''
                    this.lawManagementVisible = false
                    this.searchData()
                    this.$notify({
                        duration:2000,
                        type:'success',
                        message:'新增成功',
                        title:'成功',
                    })
                }else{
                    this.$message({
                        type:'warning',
                        message:res.data.message
                    })
                }
            }else{
                let res = await updateLawAndSafety(formData)
                if(res.data.code === '200'){
                    this.$refs["upload"].value = ''
                    this.lawManagementVisible = false
                    this.searchData()
                    this.$notify({
                        duration:2000,
                        type:'success',
                        message:'修改成功',
                        title:'成功',
                    })
                }else{
                    this.$message({
                        type:'warning',
                        message:res.data.message
                    })
                }
            }

        },

        deleteById(row){
            this.$confirm('删除此条信息，是否继续','提示',{
                confirmButtonText:'确定',
                cancelButtonText:'取消',
                type:'warning',
            }).then(()=> {
                deleteLawAndSafety(row.id).then( ()=>{
                    this.getLawManagementListData()
                    this.$notify({
                        title:'成功',
                        message:'删除成功',
                        type:'success',
                        duration:2000,
                    })
                })
            })
        },
    }
}
</script>

<style scoped>
/*/deep/ .el-input__inner {*/
/*    width:300px;*/
/*}*/
/*/deep/.el-textarea__inner{*/
/*    width:300px;*/
/*}*/
.content_qw{
    width:300px;
}
.basic_search{
    display:inline-block;
}
</style>
